@@ -33,6 +33,7 @@ class HBWebsocket:
         self._addr = addr
         self.sub_dict = {}  # 订阅列表
         self.__handlers = []  # 对message做处理的处理函数或处理类
+        self.__req_callbacks = {}
         self.__handle_funcs = {}
         self.ctx = zmq_ctx
         self.pub_socket = self.ctx.socket(zmq.PUB)
@@ -71,6 +72,16 @@ class HBWebsocket:
                     )
                 elif 'rep' in msg:
                     logger.info(f'<请求>Topic:{msg["rep"]}请求数据成功 #{msg["id"]}#')
+                    OnRsp = self.__req_callbacks.get(msg['rep'], [])
+                    def callbackThread(_m):
+                        for cb in OnRsp:
+                            try:
+                                cb(_m)
+                            except Exception as e:
+                                logger.error(f'<请求回调>{msg["rep"]}的回调函数{cb.__name__}异常-{e}')
+                    _t = Thread(target=callbackThread, args=(msg, ))
+                    _t.setDaemon(True)
+                    _t.start()
             elif msg['status'] == 'error':
                 logger.error(
                     f'<错误>{msg.get("id")}-ErrTime:{dt.datetime.fromtimestamp(msg["ts"] / 1000)} ErrCode:{msg["err-code"]} ErrMsg:{msg["err-msg"]}'
@@ -79,11 +90,11 @@ class HBWebsocket:
             logger.debug(f'{msg}')
             self.pub_msg(msg)
 
-    def pub_msg(self,
-                msg):  # 核心的处理函数，如果是handle_func直接处理，如果是handler，推送到handler的队列
+    def pub_msg(self, msg):
+        """核心的处理函数，如果是handle_func直接处理，如果是handler，推送到handler的队列"""
         if 'ch' in msg:
             self.pub_socket.send_multipart(
-                [msg['ch'].encode(), pickle.dumps(msg)])
+                [pickle.dumps(msg['ch']), pickle.dumps(msg)])
 
         if 'ch' in msg or 'rep' in msg:
             topic = msg.get('ch') or msg.get('rep')
@@ -109,6 +120,15 @@ class HBWebsocket:
         else:
             logger.info(f'<订阅>初始化订阅完成')
 
+    def register_onRsp(self, req):
+        def wrapper(_callback):
+            callbackList = self.__req_callbacks.setdefault(req, [])
+            callbackList.append(_callback)
+        return wrapper
+
+    def unregister_onRsp(self, req):
+        return self.__req_callbacks.pop(req)
+
     def register_handler(self, handler):  # 注册handler
         if handler not in self.__handlers:
             self.__handlers.append(handler)
@@ -128,8 +148,8 @@ class HBWebsocket:
 
         return _wrapper
 
-    def unregister_handle_func(self, _handle_func_name,
-                               topic):  # 注销handle_func
+    def unregister_handle_func(self, _handle_func_name, topic):
+        """ 注销handle_func """
         handler_list = self.__handle_funcs.get(topic, [])
         for i, h in enumerate(handler_list):
             if h is _handle_func_name:
@@ -143,9 +163,13 @@ class HBWebsocket:
         return self.__handlers
 
     @property
-    def handle_funs(self):
+    def handle_funcs(self):
         return self.__handle_funcs
 
+    @property
+    def OnRsp_callbacks(self):
+        return self.__req_callbacks
+
     @staticmethod
     def _check_info(**kwargs):
         log = []
@@ -212,17 +236,27 @@ class HBWebsocket:
             self.send_message(msg)
             logger.info(f'<订阅>tick-发送取消订阅请求*{symbol}* #{_id}#')
 
+    def sub_all_lastest_24h_ohlc(self, _id=''):
+        msg = {'sub': f'market.tickers', 'id': _id}
+        self.send_message(msg)
+        logger.info(f'<订阅>all_ticks-发送订阅请求 #{_id}#')
+
+    def unsub_all_lastest_24h_ohlc(self, _id=''):
+        msg = {'unsub': f'market.tickers', 'id': _id}
+        self.send_message(msg)
+        logger.info(f'<订阅>all_ticks-发送取消订阅请求 #{_id}#')
+
     def rep_kline(self, symbol, period, _id='', **kwargs):
         if self._check_info(symbol=symbol, period=period):
             msg = {'req': f'market.{symbol}.kline.{period}', 'id': _id}
-            if 'from' in kwargs:
-                _from = parser.parse(kwargs['from']) if isinstance(
-                    kwargs['from'], str) else kwargs['from']
-                msg.update({'from': _from})
-            if 'to' in kwargs:
-                _to = parser.parse(kwargs['to']) if isinstance(
-                    kwargs['to'], str) else kwargs['to']
-                msg.update({'to': _to})
+            if '_from' in kwargs:
+                _from = parser.parse(kwargs['_from']).timestamp() if isinstance(
+                    kwargs['_from'], str) else kwargs['_from']
+                msg.update({'from': int(_from)})
+            if '_to' in kwargs:
+                _to = parser.parse(kwargs['_to']).timestamp() if isinstance(
+                    kwargs['_to'], str) else kwargs['_to']
+                msg.update({'to': int(_to)})
             self.send_message(msg)
             logger.info(f'<请求>kline-发送请求*{symbol}*@{period} #{_id}#')
 
@@ -274,12 +308,28 @@ class HBRestAPI:
         if keys:
             setKey(*keys)
         if get_acc:
-            self.acc_id = self.get_accounts()['data'][0]['id']
+            try:
+                self.acc_id = self.get_accounts()['data'][0]['id']
+            except Exception as e:
+                raise Exception(f'Failed to get account: key may not be set ->{e}')
 
     def set_acc_id(self, acc_id):
         self.acc_id = acc_id
 
-    def get_kline(self, symbol, period, size=150):
+    def __async_request_exception_handler(self, req, e):
+        logger.error(f'async_request:{req}--exception:{e}')
+
+    def async_request(self, reqs:list)->list:
+        """
+        异步并发请求
+        :param reqs: 请求列表
+        :return:
+        """
+        result = (response.result() for response in reqs)
+        ret = [r.json() if r.status_code == 200 else None for r in result]
+        return ret
+
+    def get_kline(self, symbol, period, size=150, _async=False):
         """
         获取KLine
         :param symbol
@@ -290,9 +340,9 @@ class HBRestAPI:
         params = {'symbol': symbol, 'period': period, 'size': size}
 
         url = u.MARKET_URL + '/market/history/kline'
-        return http_get_request(url, params)
+        return http_get_request(url, params, _async=_async)
 
-    def get_latest_depth(self, symbol, _type):
+    def get_latest_depth(self, symbol, _type, _async=False):
         """
          获取marketdepth
         :param symbol
@@ -302,9 +352,9 @@ class HBRestAPI:
         params = {'symbol': symbol, 'type': _type}
 
         url = u.MARKET_URL + '/market/depth'
-        return http_get_request(url, params)
+        return http_get_request(url, params, _async=_async)
 
-    def get_latest_ticker(self, symbol):
+    def get_latest_ticker(self, symbol, _async=False):
         """
         获取tradedetail
         :param symbol
@@ -313,9 +363,9 @@ class HBRestAPI:
         params = {'symbol': symbol}
 
         url = u.MARKET_URL + '/market/trade'
-        return http_get_request(url, params)
+        return http_get_request(url, params, _async=_async)
 
-    def get_ticker(self, symbol, size=1):
+    def get_ticker(self, symbol, size=1, _async=False):
         """
         获取历史ticker
         :param symbol:
@@ -325,9 +375,19 @@ class HBRestAPI:
         params = {'symbol': symbol, 'size': size}
 
         url = u.MARKET_URL + '/market/history/trade'
-        return http_get_request(url, params)
+        return http_get_request(url, params, _async=_async)
 
-    def get_latest_1m_ohlc(self, symbol):
+    def get_all_lastest_24h_ohlc(self, _async=False):
+        """
+        获取所有24小时的概况
+        :param _async:
+        :return:
+        """
+        params = {}
+        url = u.MARKET_URL + '/market/tickers'
+        return http_get_request(url, params, _async=_async)
+
+    def get_latest_1m_ohlc(self, symbol, _async=False):
         """
         获取最新一分钟的k线
         :param symbol:
@@ -336,9 +396,9 @@ class HBRestAPI:
         params = {'symbol': symbol}
 
         url = u.MARKET_URL + '/market/detail/merged'
-        return http_get_request(url, params)
+        return http_get_request(url, params, _async=_async)
 
-    def get_lastest_24H_detail(self, symbol):
+    def get_lastest_24h_ohlc(self, symbol, _async=False):
         """
         获取最近24小时的概况
         :param symbol
@@ -347,9 +407,9 @@ class HBRestAPI:
         params = {'symbol': symbol}
 
         url = u.MARKET_URL + '/market/detail'
-        return http_get_request(url, params)
+        return http_get_request(url, params, _async=_async)
 
-    def get_symbols(self, site='Pro'):
+    def get_symbols(self, site='Pro', _async=False):
         """
         获取  支持的交易对
         :param site:
@@ -358,9 +418,9 @@ class HBRestAPI:
         assert site in ['Pro', 'HADAX']
         params = {}
         path = f'/v1{"/" if site == "Pro" else "/hadax/"}common/symbols'
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
-    def get_currencys(self, site='Pro'):
+    def get_currencys(self, site='Pro', _async=False):
         """
         获取所有币种
         :param site:
@@ -369,37 +429,37 @@ class HBRestAPI:
         assert site in ['Pro', 'HADAX']
         params = {}
         path = f'/v1{"/" if site == "Pro" else "/hadax/"}common/currencys'
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
-    def get_timestamp(self):
+    def get_timestamp(self, _async=False):
         params = {}
         path = '/v1/common/timestamp'
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
     '''
     Trade/Account API
     '''
 
-    def get_accounts(self):
+    def get_accounts(self, _async=False):
         """
         :return:
         """
         path = '/v1/account/accounts'
         params = {}
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
-    def get_balance(self, site='Pro'):
+    def get_balance(self, acc_id, site='Pro', _async=False):
         """
         获取当前账户资产
         :return:
         """
         assert site in ['Pro', 'HADAX']
-        path = f'/v1{"/" if site == "Pro" else "/hadax/"}account/accounts/{self.acc_id}/balance'
+        path = f'/v1{"/" if site == "Pro" else "/hadax/"}account/accounts/{acc_id}/balance'
         # params = {'account-id': self.acct_id}
         params = {}
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
-    def send_order(self, amount, symbol, _type, price=0, site='Pro'):
+    def send_order(self, acc_id, amount, symbol, _type, price=0, site='Pro', _async=False):
         """
         创建并执行订单
         :param amount:
@@ -412,7 +472,7 @@ class HBRestAPI:
         assert site in ['Pro', 'HADAX']
         assert _type in u.ORDER_TYPE
         params = {
-            'account-id': self.acc_id,
+            'account-id': acc_id,
             'amount': amount,
             'symbol': symbol,
             'type': _type,
@@ -422,9 +482,9 @@ class HBRestAPI:
             params['price'] = price
 
         path = f'/v1{"/" if site == "Pro" else "/hadax/"}order/orders/place'
-        return api_key_post(params, path)
+        return api_key_post(params, path, _async=_async)
 
-    def cancel_order(self, order_id):
+    def cancel_order(self, order_id, _async=False):
         """
         撤销订单
         :param order_id:
@@ -432,9 +492,9 @@ class HBRestAPI:
         """
         params = {}
         path = f'/v1/order/orders/{order_id}/submitcancel'
-        return api_key_post(params, path)
+        return api_key_post(params, path, _async=_async)
 
-    def batchcancel_order(self, order_ids: list):
+    def batchcancel_order(self, order_ids: list, _async=False):
         """
         批量撤销订单
         :param order_id:
@@ -443,9 +503,9 @@ class HBRestAPI:
         assert isinstance(order_ids, list)
         params = {'order-ids': order_ids}
         path = f'/v1/order/orders/batchcancel'
-        return api_key_post(params, path)
+        return api_key_post(params, path, _async=_async)
 
-    def get_order_info(self, order_id):
+    def get_order_info(self, order_id, _async=False):
         """
         查询某个订单
         :param order_id:
@@ -453,9 +513,9 @@ class HBRestAPI:
         """
         params = {}
         path = f'/v1/order/orders/{order_id}'
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
-    def get_order_matchresults(self, order_id):
+    def get_order_matchresults(self, order_id, _async=False):
         """
         查询某个订单的成交明细
         :param order_id:
@@ -463,17 +523,18 @@ class HBRestAPI:
         """
         params = {}
         path = f'/v1/order/orders/{order_id}/matchresults'
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
     def get_orders_info(self,
                         symbol,
-                        states,
-                        types=None,
+                        states:list,
+                        types:list=None,
                         start_date=None,
                         end_date=None,
                         _from=None,
                         direct=None,
-                        size=None):
+                        size=None,
+                        _async=False):
         """
         查询当前委托、历史委托
         :param symbol:
@@ -486,14 +547,17 @@ class HBRestAPI:
         :param size:
         :return:
         """
+        states = ','.join(states)
         params = {'symbol': symbol, 'states': states}
 
         if types:
-            params[types] = types
+            params['types'] = ','.join(types)
         if start_date:
-            params['start-date'] = start_date
+            sd = parser.parse(start_date).date()
+            params['start-date'] = str(sd)
         if end_date:
-            params['end-date'] = end_date
+            ed = parser.parse(end_date).date()
+            params['end-date'] = str(ed)
         if _from:
             params['from'] = _from
         if direct:
@@ -502,16 +566,17 @@ class HBRestAPI:
         if size:
             params['size'] = size
         path = '/v1/order/orders'
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
     def get_orders_matchresults(self,
                                 symbol,
-                                types=None,
+                                types:list=None,
                                 start_date=None,
                                 end_date=None,
                                 _from=None,
                                 direct=None,
-                                size=None):
+                                size=None,
+                                _async=False):
         """
         查询当前成交、历史成交
         :param symbol:
@@ -526,11 +591,13 @@ class HBRestAPI:
         params = {'symbol': symbol}
 
         if types:
-            params[types] = types
+            params['types'] = ','.join(types)
         if start_date:
-            params['start-date'] = start_date
+            sd = parser.parse(start_date).date()
+            params['start-date'] = str(sd)
         if end_date:
-            params['end-date'] = end_date
+            ed = parser.parse(end_date).date()
+            params['end-date'] = str(ed)
         if _from:
             params['from'] = _from
         if direct:
@@ -538,9 +605,9 @@ class HBRestAPI:
         if size:
             params['size'] = size
         path = '/v1/order/matchresults'
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
-    def req_withdraw(self, address, amount, currency, fee=0, addr_tag=""):
+    def req_withdraw(self, address, amount, currency, fee=0, addr_tag="", _async=False):
         """
         申请提现虚拟币
         :param address:
@@ -562,9 +629,9 @@ class HBRestAPI:
         }
         path = '/v1/dw/withdraw/api/create'
 
-        return api_key_post(params, path)
+        return api_key_post(params, path, _async=_async)
 
-    def cancel_withdraw(self, address_id):
+    def cancel_withdraw(self, address_id, _async=False):
         """
         申请取消提现虚拟币
         :param address_id:
@@ -576,9 +643,9 @@ class HBRestAPI:
         params = {}
         path = f'/v1/dw/withdraw-virtual/{address_id}/cancel'
 
-        return api_key_post(params, path)
+        return api_key_post(params, path, _async=_async)
 
-    def get_deposit_withdraw_record(self, currency, _type, _from, size):
+    def get_deposit_withdraw_record(self, currency, _type, _from, size, _async=False):
         """
 
         :param currency:
@@ -595,13 +662,13 @@ class HBRestAPI:
             'size': size
         }
         path = '/v1/query/deposit-withdraw'
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
     '''
     借贷API
     '''
 
-    def send_margin_order(self, amount, symbol, _type, price=0):
+    def send_margin_order(self, acc_id, amount, symbol, _type, price=0, _async=False):
         """
         创建并执行借贷订单
         :param amount:
@@ -612,7 +679,7 @@ class HBRestAPI:
         """
 
         params = {
-            'account-id': self.acc_id,
+            'account-id': acc_id,
             'amount': amount,
             'symbol': symbol,
             'type': _type,
@@ -622,9 +689,9 @@ class HBRestAPI:
             params['price'] = price
 
         path = '/v1/order/orders/place'
-        return api_key_post(params, path)
+        return api_key_post(params, path, _async=_async)
 
-    def exchange_to_margin(self, symbol, currency, amount):
+    def exchange_to_margin(self, symbol, currency, amount, _async=False):
         """
         现货账户划入至借贷账户
         :param amount:
@@ -635,9 +702,9 @@ class HBRestAPI:
         params = {'symbol': symbol, 'currency': currency, 'amount': amount}
 
         path = '/v1/dw/transfer-in/margin'
-        return api_key_post(params, path)
+        return api_key_post(params, path, _async=_async)
 
-    def margin_to_exchange(self, symbol, currency, amount):
+    def margin_to_exchange(self, symbol, currency, amount, _async=False):
         """
         借贷账户划出至现货账户
         :param amount:
@@ -648,9 +715,9 @@ class HBRestAPI:
         params = {'symbol': symbol, 'currency': currency, 'amount': amount}
 
         path = '/v1/dw/transfer-out/margin'
-        return api_key_post(params, path)
+        return api_key_post(params, path, _async=_async)
 
-    def req_margin(self, symbol, currency, amount):
+    def apply_loan(self, symbol, currency, amount, _async=False):
         """
         申请借贷
         :param amount:
@@ -660,9 +727,9 @@ class HBRestAPI:
         """
         params = {'symbol': symbol, 'currency': currency, 'amount': amount}
         path = '/v1/margin/orders'
-        return api_key_post(params, path)
+        return api_key_post(params, path, _async=_async)
 
-    def repay_margin(self, order_id, amount):
+    def repay_loan(self, order_id, amount, _async=False):
         """
         归还借贷
         :param order_id:
@@ -671,38 +738,38 @@ class HBRestAPI:
         """
         params = {'order-id': order_id, 'amount': amount}
         path = f'/v1/margin/orders/{order_id}/repay'
-        return api_key_post(params, path)
+        return api_key_post(params, path, _async=_async)
 
     def get_loan_orders(self,
                         symbol,
                         currency,
-                        start_date="",
-                        end_date="",
-                        start="",
-                        direct="",
-                        size=""):
-        """
-        借贷订单
-        :param symbol:
-        :param currency:
-        :param direct: prev 向前，next 向后
-        :return:
-        """
+                        states=None,
+                        start_date=None,
+                        end_date=None,
+                        _from=None,
+                        direct=None,
+                        size=None,
+                        _async=False):
+
         params = {'symbol': symbol, 'currency': currency}
+        if states:
+            params['states'] = states
         if start_date:
-            params['start-date'] = start_date
+            sd = parser.parse(start_date).date()
+            params['start-date'] = str(sd)
         if end_date:
-            params['end-date'] = end_date
-        if start:
-            params['from'] = start
+            ed = parser.parse(end_date).date()
+            params['end_date'] = str(ed)
+        if _from:
+            params['from'] = _from
         if direct and direct in ['prev', 'next']:
             params['direct'] = direct
         if size:
             params['size'] = size
         path = '/v1/margin/loan-orders'
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
-    def get_margin_balance(self, symbol):
+    def get_margin_balance(self, symbol, _async=False):
         """
         借贷账户详情,支持查询单个币种
         :param symbol:
@@ -713,7 +780,7 @@ class HBRestAPI:
         if symbol:
             params['symbol'] = symbol
 
-        return api_key_get(params, path)
+        return api_key_get(params, path, _async=_async)
 
 
 class HBRestAPI_DEC():
@@ -729,7 +796,10 @@ class HBRestAPI_DEC():
         if key:
             setKey(*key)
         if get_acc:
-            self.acc_id = self.get_accounts()['data'][0]['id']
+            @self.get_accounts()
+            def set_acc(msg):
+                self.acc_id = msg['data'][0]['id']
+            set_acc()
 
     def set_acc_id(self, acc_id):
         self.acc_id = acc_id
@@ -813,6 +883,25 @@ class HBRestAPI_DEC():
 
         return _wrapper
 
+    def get_all_lastest_24h_ohlc(self):
+        """
+        获取所有ticker
+        :param _async:
+        :return:
+        """
+        params = {}
+        url = u.MARKET_URL + '/market/tickers'
+
+        def _wrapper(_func):
+            @wraps(_func)
+            def handle():
+                _func(http_get_request(url, params))
+
+            return handle
+
+        return _wrapper
+
+
     def get_latest_1m_ohlc(self, symbol):
         """
         获取最新一分钟的kline
@@ -832,7 +921,7 @@ class HBRestAPI_DEC():
 
         return _wrapper
 
-    def get_lastest_24H_detail(self, symbol):
+    def get_lastest_24h_ohlc(self, symbol):
         """
         获取 Market Detail 24小时成交量数据
         :param symbol
@@ -921,13 +1010,13 @@ class HBRestAPI_DEC():
 
         return _wrapper
 
-    def get_balance(self, site='Pro'):
+    def get_balance(self, acc_id, site='Pro'):
         """
         获取当前账户资产
         :return:
         """
         assert site in ['Pro', 'HADAX']
-        path = f'/v1{"/" if site == "Pro" else "/hadax/"}account/accounts/{self.acc_id}/balance'
+        path = f'/v1{"/" if site == "Pro" else "/hadax/"}account/accounts/{acc_id}/balance'
         # params = {'account-id': self.acct_id}
         params = {}
 
@@ -940,7 +1029,7 @@ class HBRestAPI_DEC():
 
         return _wrapper
 
-    def send_order(self, amount, symbol, _type, price=0, site='Pro'):
+    def send_order(self, acc_id, amount, symbol, _type, price=0, site='Pro'):
         """
         创建并执行订单
         :param amount:
@@ -953,7 +1042,7 @@ class HBRestAPI_DEC():
         assert site in ['Pro', 'HADAX']
         assert _type in u.ORDER_TYPE
         params = {
-            'account-id': self.acc_id,
+            'account-id': acc_id,
             'amount': amount,
             'symbol': symbol,
             'type': _type,
@@ -1070,11 +1159,13 @@ class HBRestAPI_DEC():
         params = {'symbol': symbol, 'states': states}
 
         if types:
-            params[types] = types
+            params['types'] = types
         if start_date:
-            params['start-date'] = start_date
+            sd = parser.parse(start_date).date()
+            params['start-date'] = str(sd)
         if end_date:
-            params['end-date'] = end_date
+            ed = parser.parse(end_date).date()
+            params['end_date'] = str(ed)
         if _from:
             params['from'] = _from
         if direct:
@@ -1115,11 +1206,13 @@ class HBRestAPI_DEC():
         params = {'symbol': symbol}
 
         if types:
-            params[types] = types
+            params['types'] = types
         if start_date:
-            params['start-date'] = start_date
+            sd = parser.parse(start_date).date()
+            params['start-date'] = str(sd)
         if end_date:
-            params['end-date'] = end_date
+            ed = parser.parse(end_date).date()
+            params['end_date'] = str(ed)
         if _from:
             params['from'] = _from
         if direct:
@@ -1220,7 +1313,7 @@ class HBRestAPI_DEC():
     借贷API
     '''
 
-    def send_margin_order(self, amount, symbol, _type, price=0):
+    def send_margin_order(self, acc_id, amount, symbol, _type, price=0):
         """
         创建并执行借贷订单
         :param amount:
@@ -1231,7 +1324,7 @@ class HBRestAPI_DEC():
         """
 
         params = {
-            'account-id': self.acc_id,
+            'account-id': acc_id,
             'amount': amount,
             'symbol': symbol,
             'type': _type,
@@ -1292,7 +1385,7 @@ class HBRestAPI_DEC():
 
         return _wrapper
 
-    def req_margin(self, symbol, currency, amount):
+    def apply_loan(self, symbol, currency, amount):
         """
         申请借贷
         :param amount:
@@ -1312,7 +1405,7 @@ class HBRestAPI_DEC():
 
         return _wrapper
 
-    def repay_margin(self, order_id, amount):
+    def repay_loan(self, order_id, amount):
         """
         归还借贷
         :param order_id:
@@ -1334,29 +1427,34 @@ class HBRestAPI_DEC():
     def get_loan_orders(self,
                         symbol,
                         currency,
-                        start_date="",
-                        end_date="",
-                        start="",
-                        direct="",
-                        size=""):
+                        states=None,
+                        start_date=None,
+                        end_date=None,
+                        _from=None,
+                        direct=None,
+                        size=None):
         """
         借贷订单
         :param symbol:
         :param currency:
         :param start_date:
         :param end_date:
-        :param start:
+        :param _from:
         :param direct:
         :param size:
         :return:
         """
         params = {'symbol': symbol, 'currency': currency}
+        if states:
+            params['states'] = states
         if start_date:
-            params['start-date'] = start_date
+            sd = parser.parse(start_date).date()
+            params['start-date'] = str(sd)
         if end_date:
-            params['end-date'] = end_date
-        if start:
-            params['from'] = start
+            ed = parser.parse(end_date).date()
+            params['end_date'] = str(ed)
+        if _from:
+            params['from'] = _from
         if direct and direct in ['prev', 'next']:
             params['direct'] = direct
         if size:
